'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var fastparse$1 = _interopDefault(require('fastparse'));

const processMatch = function processMatch(match, strUntilValue, name, value, index) {
  if (!this.isRelevantTagAttr(this.currentTag, name)) return;
  this.results.push({
    start: index + strUntilValue.length,
    length: value.length,
    value,
  });
};

const parser = new fastparse$1({
  outside: {
    '<!--.*?-->': true,
    '<![CDATA[.*?]]>': true,
    '<[!\\?].*?>': true,
    '</[^>]+>': true,
    '<([a-zA-Z\\-:]+)\\s*': function matchTag(match, tagName) {
      this.currentTag = tagName;
      return 'inside';
    },
  },
  inside: {
    '\\s+': true, // eat up whitespace
    '>': 'outside', // end of attributes
    '(([0-9a-zA-Z\\-:]+)\\s*=\\s*")([^"]*)"': processMatch,
    "(([0-9a-zA-Z\\-:]+)\\s*=\\s*')([^']*)'": processMatch,
    '(([0-9a-zA-Z\\-:]+)\\s*=\\s*)([^\\s>]+)': processMatch,
  },
});

var attributesParser = function parse(html, isRelevantTagAttr) {
  return parser.parse('outside', html, {
    currentTag: null,
    results: [],
    isRelevantTagAttr,
  }).results;
};

const CODE = {
  pass: 0,
  pre: 1,
};
const sliceUp = function sliceUp(text, replaceList) {
  let cursor = 0;
  const cache = [];
  replaceList.forEach(({ start, length, value }) => {
    const preStr = text.slice(cursor, start);
    cursor = start + length;
    cache.push({
      code: CODE.pass,
      text: preStr,
    });
    cache.push({
      code: CODE.pre,
      text: value,
    });
  });
  cache.push({
    code: CODE.pass,
    text: text.slice(cursor),
  });
  return cache;
};
const rev = sourceMap => ({ code, text }) => {
  if (code === CODE.pre && text in sourceMap) {
    return sourceMap[text];
  }
  return text;
};
const replace = function replace(text, replaceList, sourceMap) {
  if (typeof text !== 'string') throw new TypeError('text must be a string');
  const list = sliceUp(text, replaceList);
  return list.map(rev(sourceMap)).join('');
};
var replace_1 = replace;

const tagMap = {
  script: 'src',
  img: 'src',
  link: 'href',
  div: 'data-videomp4',
  use: 'xlink:href',
};

var index = function parse(html, sourceMap) {
  const replaceList = attributesParser(html, (tag, attr) => tagMap[tag] === attr);
  return replace_1(html, replaceList, sourceMap);
};

module.exports = index;
//# sourceMappingURL=index.js.map
